@@ -38,6 +38,11 @@ def proxy(key):
         def __delattr__(self, attr):
             obj = getattr(state, key)
             return delattr(obj, attr)
+
+        def __dir__(self):
+            obj = getattr(state, key)
+            return dir(obj)
+
     return ObjectProxy()
 
 
@@ -138,8 +143,8 @@ def load_app(config):
     Used to load a ``Pecan`` application and its environment based on passed
     configuration.
 
-    :param config: Can be a dictionary containing configuration, or a string
-                   which represents a (relative) configuration filename.
+    :param config: Can be a dictionary containing configuration, a string which
+                    represents a (relative) configuration filename
 
     returns a pecan.Pecan object
     '''
@@ -363,8 +368,9 @@ class Pecan(object):
         # get a sorted list of hooks, by priority (no controller hooks yet)
         state.hooks = self.determine_hooks()
 
-        # store the routing path to allow hooks to modify it
-        request.pecan['routing_path'] = request.path
+        # store the routing path for the current application to allow hooks to
+        # modify it
+        request.pecan['routing_path'] = request.path_info
 
         # handle "on_route" hooks
         self.handle_hooks('on_route', state)
