@@ -1,12 +1,13 @@
 import sys
+import os
 import warnings
-from webtest import TestApp
-
 if sys.version_info < (2, 7):
     import unittest2 as unittest  # pragma: nocover
 else:
     import unittest  # pragma: nocover
 
+from webtest import TestApp
+
 from pecan import (
     Pecan, expose, request, response, redirect, abort, make_app,
     override_template, render
@@ -15,22 +16,21 @@ from pecan.templating import (
     _builtin_renderers as builtin_renderers, error_formatters
 )
 from pecan.decorators import accept_noncanonical
-
-import os
+from pecan.tests import PecanTestCase
 
 
 class SampleRootController(object):
     pass
 
 
-class TestAppRoot(unittest.TestCase):
+class TestAppRoot(PecanTestCase):
 
     def test_controller_lookup_by_string_path(self):
         app = Pecan('pecan.tests.test_base.SampleRootController')
         assert app.root and isinstance(app.root, SampleRootController)
 
 
-class TestIndexRouting(unittest.TestCase):
+class TestIndexRouting(PecanTestCase):
 
     @property
     def app_(self):
@@ -57,7 +57,7 @@ class TestIndexRouting(unittest.TestCase):
         assert r.body == 'Hello, World!'
 
 
-class TestObjectDispatch(unittest.TestCase):
+class TestObjectDispatch(PecanTestCase):
 
     @property
     def app_(self):
@@ -124,7 +124,7 @@ class TestObjectDispatch(unittest.TestCase):
         assert r.body == '/sub/sub/deeper'
 
 
-class TestLookups(unittest.TestCase):
+class TestLookups(PecanTestCase):
 
     @property
     def app_(self):
@@ -179,7 +179,7 @@ class TestLookups(unittest.TestCase):
             assert r.status_int == 404
 
 
-class TestControllerArguments(unittest.TestCase):
+class TestControllerArguments(PecanTestCase):
 
     @property
     def app_(self):
@@ -702,7 +702,7 @@ class TestControllerArguments(unittest.TestCase):
         assert r.body == 'eater: 10, dummy, day=12, month=1'
 
 
-class TestAbort(unittest.TestCase):
+class TestAbort(PecanTestCase):
 
     def test_abort(self):
         class RootController(object):
@@ -725,7 +725,24 @@ class TestAbort(unittest.TestCase):
         assert r.status_int == 401
 
 
-class TestRedirect(unittest.TestCase):
+class TestScriptName(PecanTestCase):
+
+    def setUp(self):
+        super(TestScriptName, self).setUp()
+        self.environ = {'SCRIPT_NAME': '/foo'}
+
+    def test_handle_script_name(self):
+        class RootController(object):
+            @expose()
+            def index(self):
+                return 'Root Index'
+
+        app = TestApp(Pecan(RootController()), extra_environ=self.environ)
+        r = app.get('/foo/')
+        assert r.status_int == 200
+
+
+class TestRedirect(PecanTestCase):
 
     @property
     def app_(self):
@@ -801,7 +818,7 @@ class TestRedirect(unittest.TestCase):
         assert res.request.environ['HTTP_X_FORWARDED_PROTO'] == 'https'
 
 
-class TestStreamedResponse(unittest.TestCase):
+class TestStreamedResponse(PecanTestCase):
 
     def test_streaming_response(self):
         import StringIO
@@ -831,7 +848,7 @@ class TestStreamedResponse(unittest.TestCase):
         assert r.body == 'plain text'
 
 
-class TestStateCleanup(unittest.TestCase):
+class TestStateCleanup(PecanTestCase):
 
     def test_request_state_cleanup(self):
         """
@@ -853,7 +870,7 @@ class TestStateCleanup(unittest.TestCase):
         assert state.__dict__.keys() == ['app']
 
 
-class TestFileTypeExtensions(unittest.TestCase):
+class TestFileTypeExtensions(PecanTestCase):
 
     @property
     def app_(self):
@@ -863,7 +880,11 @@ class TestFileTypeExtensions(unittest.TestCase):
         class RootController(object):
             @expose(content_type=None)
             def _default(self, *args):
-                return request.pecan['extension']
+                ext = request.pecan['extension']
+                assert len(args) == 1
+                if ext:
+                    assert ext not in args[0]
+                return ext or ''
 
         return TestApp(Pecan(RootController()))
 
@@ -883,7 +904,7 @@ class TestFileTypeExtensions(unittest.TestCase):
         assert r.body == ''
 
     def test_multi_dot_extension(self):
-        r = self.app_.get('/gradient.js.js')
+        r = self.app_.get('/gradient.min.js')
         assert r.status_int == 200
         assert r.body == '.js'
 
@@ -907,8 +928,85 @@ class TestFileTypeExtensions(unittest.TestCase):
             r = app.get('/index.txt', expect_errors=True)
             assert r.status_int == 404
 
+    def test_unknown_file_extension(self):
+        class RootController(object):
+            @expose(content_type=None)
+            def _default(self, *args):
+                assert 'example:x.tiny' in args
+                assert request.pecan['extension'] is None
+                return 'SOME VALUE'
 
-class TestCanonicalRouting(unittest.TestCase):
+        app = TestApp(Pecan(RootController()))
+
+        r = app.get('/example:x.tiny')
+        assert r.status_int == 200
+        assert r.body == 'SOME VALUE'
+
+    def test_guessing_disabled(self):
+        class RootController(object):
+            @expose(content_type=None)
+            def _default(self, *args):
+                assert 'index.html' in args
+                assert request.pecan['extension'] is None
+                return 'SOME VALUE'
+
+        app = TestApp(Pecan(RootController(),
+                            guess_content_type_from_ext=False))
+
+        r = app.get('/index.html')
+        assert r.status_int == 200
+        assert r.body == 'SOME VALUE'
+
+
+class TestContentTypeByAcceptHeaders(PecanTestCase):
+
+    @property
+    def app_(self):
+        """
+        Test that content type is set appropriately based on Accept headers.
+        """
+        class RootController(object):
+
+            @expose(content_type='text/html')
+            @expose(content_type='application/json')
+            def index(self, *args):
+                return 'Foo'
+
+        return TestApp(Pecan(RootController()))
+
+    def test_quality(self):
+        r = self.app_.get('/', headers={
+            'Accept': 'text/html,application/json;q=0.9,*/*;q=0.8'
+        })
+        assert r.status_int == 200
+        assert r.content_type == 'text/html'
+
+        r = self.app_.get('/', headers={
+            'Accept': 'application/json,text/html;q=0.9,*/*;q=0.8'
+        })
+        assert r.status_int == 200
+        assert r.content_type == 'application/json'
+
+    def test_file_extension_has_higher_precedence(self):
+        r = self.app_.get('/index.html', headers={
+            'Accept': 'application/json,text/html;q=0.9,*/*;q=0.8'
+        })
+        assert r.status_int == 200
+        assert r.content_type == 'text/html'
+
+    def test_not_acceptable(self):
+        r = self.app_.get('/', headers={
+            'Accept': 'application/xml',
+        }, status=406)
+        assert r.status_int == 406
+
+    def test_accept_header_missing(self):
+        r = self.app_.get('/')
+        assert r.status_int == 200
+        assert r.content_type == 'text/html'
+
+
+class TestCanonicalRouting(PecanTestCase):
 
     @property
     def app_(self):
@@ -994,7 +1092,7 @@ class TestCanonicalRouting(unittest.TestCase):
         assert 'accept' == r.body
 
 
-class TestNonCanonical(unittest.TestCase):
+class TestNonCanonical(PecanTestCase):
 
     @property
     def app_(self):
@@ -1050,9 +1148,9 @@ class TestNonCanonical(unittest.TestCase):
             @expose()
             def index(self):
                 request.testing = True
-                assert request.testing == True
+                assert request.testing is True
                 del request.testing
-                assert hasattr(request, 'testing') == False
+                assert hasattr(request, 'testing') is False
                 return '/'
 
         app = TestApp(make_app(RootController(), debug=True))
@@ -1073,7 +1171,7 @@ class TestNonCanonical(unittest.TestCase):
         assert len(wrapped_apps) == 1
 
 
-class TestLogging(unittest.TestCase):
+class TestLogging(PecanTestCase):
 
     def test_logging_setup(self):
         class RootController(object):
@@ -1135,7 +1233,7 @@ class TestLogging(unittest.TestCase):
         assert f.getvalue() == 'HELLO WORLD\n'
 
 
-class TestEngines(unittest.TestCase):
+class TestEngines(PecanTestCase):
 
     template_path = os.path.join(os.path.dirname(__file__), 'templates')
 
@@ -1295,8 +1393,7 @@ class TestEngines(unittest.TestCase):
                 return render('mako.html', dict(name=name))
 
         app = TestApp(
-            Pecan(RootController(),
-            template_path=self.template_path)
+            Pecan(RootController(), template_path=self.template_path)
         )
         r = app.get('/')
         assert r.status_int == 200
